pub struct PmTilesWriter { /* private fields */ }Expand description
Builder for creating a new writer.
Implementations
Sourceimpl PmTilesWriter
impl PmTilesWriter
Sourcepub fn internal_compression(self, compression: Compression) -> Self
pub fn internal_compression(self, compression: Compression) -> Self
Set the compression for metadata and directories using a default compressor.
For custom compression parameters, use internal_codec instead.
Sourcepub fn tile_compression(self, compression: Compression) -> Self
pub fn tile_compression(self, compression: Compression) -> Self
Set the compression for tile data using a default compressor.
For custom compression parameters, use tile_codec instead.
Sourcepub fn tile_codec(self, compressor: impl Compressor + 'static) -> Self
pub fn tile_codec(self, compressor: impl Compressor + 'static) -> Self
Set the tile compressor. Also sets the header’s tile compression.
Sourcepub fn internal_codec(self, compressor: impl Compressor + 'static) -> Self
pub fn internal_codec(self, compressor: impl Compressor + 'static) -> Self
Set the internal (metadata/directory) compressor.
Sourcepub fn bounds(
self,
min_lon: f64,
min_lat: f64,
max_lon: f64,
max_lat: f64,
) -> Self
pub fn bounds( self, min_lon: f64, min_lat: f64, max_lon: f64, max_lat: f64, ) -> Self
Set the bounds of the tiles
Sourcepub fn center_zoom(self, level: u8) -> Self
pub fn center_zoom(self, level: u8) -> Self
Set the center zoom level.